@@ -78,40 +78,40 @@ typedef struct LineBuffer {
 
 
 static bool
-ensure_space(LineBuffer *b, size_t num) {
-    if (b->pos + num >= b->capacity) {
-        size_t new_cap = MAX(b->capacity * 2, 4096u);
-        new_cap = MAX(b->pos + num + 1024u, new_cap);
-        b->buf = realloc(b->buf, new_cap * sizeof(b->buf[0]));
-        if (!b->buf) { PyErr_NoMemory(); return false; }
-        b->capacity = new_cap;
+ensure_space(LineBuffer *lb, size_t num) {
+    if (lb->pos + num >= lb->capacity) {
+        size_t new_cap = MAX(lb->capacity * 2, 4096u);
+        new_cap = MAX(lb->pos + num + 1024u, new_cap);
+        lb->buf = realloc(lb->buf, new_cap * sizeof(lb->buf[0]));
+        if (!lb->buf) { PyErr_NoMemory(); return false; }
+        lb->capacity = new_cap;
     }
     return true;
 }
 
 static bool
-insert_code(PyObject *code, LineBuffer *b) {
+insert_code(PyObject *code, LineBuffer *lb) {
     unsigned int csz = PyUnicode_GET_LENGTH(code);
-    if (!ensure_space(b, csz)) return false;
-    for (unsigned int s = 0; s < csz; s++) b->buf[b->pos++] = PyUnicode_READ(PyUnicode_KIND(code), PyUnicode_DATA(code), s);
+    if (!ensure_space(lb, csz)) return false;
+    for (unsigned int s = 0; s < csz; s++) lb->buf[lb->pos++] = PyUnicode_READ(PyUnicode_KIND(code), PyUnicode_DATA(code), s);
     return true;
 }
 
 static bool
-add_line(Segment *bg_segment, Segment *fg_segment, LineBuffer *b, PyObject *ans) {
+add_line(Segment *bg_segment, Segment *fg_segment, LineBuffer *lb, PyObject *ans) {
     bool bg_is_active = bg_segment->current_pos == bg_segment->end_pos, fg_is_active = fg_segment->current_pos == fg_segment->end_pos;
-    if (bg_is_active) { if(!insert_code(bg_segment->end_code, b)) return false; }
-    if (fg_is_active) { if(!insert_code(fg_segment->end_code, b)) return false; }
-    PyObject *wl = PyUnicode_FromKindAndData(PyUnicode_4BYTE_KIND, b->buf, b->pos);
+    if (bg_is_active) { if(!insert_code(bg_segment->end_code, lb)) return false; }
+    if (fg_is_active) { if(!insert_code(fg_segment->end_code, lb)) return false; }
+    PyObject *wl = PyUnicode_FromKindAndData(PyUnicode_4BYTE_KIND, lb->buf, lb->pos);
     if (!wl) return false;
     int ret = PyList_Append(ans, wl); Py_DECREF(wl); if (ret != 0) return false;
-    b->pos = 0;
-    if (bg_is_active) { if(!insert_code(bg_segment->start_code, b)) return false; }
-    if (fg_is_active) { if(!insert_code(fg_segment->start_code, b)) return false; }
+    lb->pos = 0;
+    if (bg_is_active) { if(!insert_code(bg_segment->start_code, lb)) return false; }
+    if (fg_is_active) { if(!insert_code(fg_segment->start_code, lb)) return false; }
     return true;
 }
 
-static LineBuffer b;
+static LineBuffer line_buffer;
 
 static PyObject*
 split_with_highlights(PyObject *self UNUSED, PyObject *args) {
@@ -132,13 +132,13 @@ split_with_highlights(PyObject *self UNUSED, PyObject *args) {
 #define NEXT_TRUNCATE_POINT truncate_point = (truncate_pos < num_truncate_pts) ? truncate_points[truncate_pos++] : UINT_MAX
     NEXT_TRUNCATE_POINT;
 
-#define INSERT_CODE(x) { CHECK_CALL(insert_code, x, &b); }
+#define INSERT_CODE(x) { CHECK_CALL(insert_code, x, &line_buffer); }
 
-#define ADD_LINE CHECK_CALL(add_line, &bg_segment.sg, &fg_segment.sg, &b, ans);
+#define ADD_LINE CHECK_CALL(add_line, &bg_segment.sg, &fg_segment.sg, &line_buffer, ans);
 
 #define ADD_CHAR(x) { \
-    if (!ensure_space(&b, 1)) { Py_CLEAR(ans); return NULL; } \
-    b.buf[b.pos++] = x; \
+    if (!ensure_space(&line_buffer, 1)) { Py_CLEAR(ans); return NULL; } \
+    line_buffer.buf[line_buffer.pos++] = x; \
 }
 #define CHECK_SEGMENT(sgp, is_fg) { \
     if (i == sgp.sg.current_pos) { \
@@ -157,7 +157,7 @@ split_with_highlights(PyObject *self UNUSED, PyObject *args) {
 }
 
     const unsigned int line_sz = PyUnicode_GET_LENGTH(line);
-    b.pos = 0;
+    line_buffer.pos = 0;
     unsigned int i = 0;
     for (; i < line_sz; i++) {
         if (i == truncate_point) { ADD_LINE; NEXT_TRUNCATE_POINT; }
@@ -165,7 +165,7 @@ split_with_highlights(PyObject *self UNUSED, PyObject *args) {
         CHECK_SEGMENT(fg_segment, true)
         ADD_CHAR(PyUnicode_READ(PyUnicode_KIND(line), PyUnicode_DATA(line), i));
     }
-    if (b.pos) ADD_LINE;
+    if (line_buffer.pos) ADD_LINE;
     return ans;
 #undef INSERT_CODE
 #undef CHECK_SEGMENT
@@ -177,7 +177,7 @@ split_with_highlights(PyObject *self UNUSED, PyObject *args) {
 
 static void
 free_resources(void) {
-    free(b.buf); b.buf = NULL; b.capacity = 0; b.pos = 0;
+    free(line_buffer.buf); line_buffer.buf = NULL; line_buffer.capacity = 0; line_buffer.pos = 0;
 }
 
 static PyMethodDef module_methods[] = {
