@@ -16,7 +16,7 @@
 #include <sys/ioctl.h>
 #include <termios.h>
 
-static inline char**
+static char**
 serialize_string_tuple(PyObject *src) {
     Py_ssize_t sz = PyTuple_GET_SIZE(src);
 
@@ -24,15 +24,24 @@ serialize_string_tuple(PyObject *src) {
     if (!ans) fatal("Out of memory");
     for (Py_ssize_t i = 0; i < sz; i++) {
         const char *pysrc = PyUnicode_AsUTF8(PyTuple_GET_ITEM(src, i));
-        size_t len = strlen(pysrc);
-        ans[i] = calloc(len + 1, sizeof(char));
-        if (ans[i] == NULL) fatal("Out of memory");
-        memcpy(ans[i], pysrc, len);
+        if (!pysrc) {
+            PyErr_Clear();
+            DECREF_AFTER_FUNCTION PyObject *u8 = PyUnicode_AsEncodedString(PyTuple_GET_ITEM(src, i), "UTF-8", "ignore");
+            if (!u8) { PyErr_Print(); fatal("couldnt parse command line"); }
+            ans[i] = calloc(PyBytes_GET_SIZE(u8) + 1, sizeof(char));
+            if (ans[i] == NULL) fatal("Out of memory");
+            memcpy(ans[i], PyBytes_AS_STRING(u8), PyBytes_GET_SIZE(u8));
+        } else {
+            size_t len = strlen(pysrc);
+            ans[i] = calloc(len + 1, sizeof(char));
+            if (ans[i] == NULL) fatal("Out of memory");
+            memcpy(ans[i], pysrc, len);
+        }
     }
     return ans;
 }
 
-static inline void
+static void
 free_string_tuple(char** data) {
     size_t i = 0;
     while(data[i]) free(data[i++]);
@@ -41,7 +50,7 @@ free_string_tuple(char** data) {
 
 extern char **environ;
 
-static inline void
+static void
 write_to_stderr(const char *text) {
     size_t sz = strlen(text);
     size_t written = 0;
@@ -58,7 +67,7 @@ write_to_stderr(const char *text) {
 
 #define exit_on_err(m) { write_to_stderr(m); write_to_stderr(": "); write_to_stderr(strerror(errno)); exit(EXIT_FAILURE); }
 
-static inline void
+static void
 wait_for_terminal_ready(int fd) {
     char data;
     while(1) {
