@@ -1,18 +1,16 @@
 #!/usr/bin/env python
-# vim:fileencoding=utf-8
 # License: GPLv3 Copyright: 2021, Kovid Goyal <kovid at kovidgoyal.net>
 
 import importlib
 import os
 import sys
 import unittest
-try:
-    from importlib.resources import contents
-except Exception:
-    from importlib_resources import contents
 from typing import Callable, Generator, NoReturn, Sequence, Set
 
 
+from importlib.resources import contents
+
+
 def itertests(suite: unittest.TestSuite) -> Generator[unittest.TestCase, None, None]:
     stack = [suite]
     while stack:
