@@ -3,14 +3,27 @@
 
 
 import os
-from . import BaseTest
 
 from kittens.ssh.main import get_connection_data
 from kitty.utils import SSHConnectionData
 
+from . import BaseTest
+
 
 class SSHTest(BaseTest):
 
+    def test_basic_pty_operations(self):
+        pty = self.create_pty('echo hello')
+        pty.process_input_from_child()
+        self.ae(pty.screen_contents(), 'hello')
+        pty = self.create_pty(self.cmd_to_run_python_code('''\
+import array, fcntl, sys, termios
+buf = array.array('H', [0, 0, 0, 0])
+fcntl.ioctl(sys.stdout, termios.TIOCGWINSZ, buf)
+print(' '.join(map(str, buf)))'''), lines=13, cols=77)
+        pty.process_input_from_child()
+        self.ae(pty.screen_contents(), '13 77 770 260')
+
     def test_ssh_connection_data(self):
         def t(cmdline, binary='ssh', host='main', port=None, identity_file=''):
             if identity_file:
